@@ -3,7 +3,9 @@
 static ID id_cmp;
 
 static VALUE
-bdb_recnum_init(int argc, VALUE *argv, VALUE obj)
+bdb_recnum_init(argc, argv, obj)
+    int argc;
+    VALUE *argv, obj;
 {
     VALUE *nargv;
     VALUE array = rb_str_new2("array_base");
@@ -25,7 +27,9 @@ bdb_recnum_init(int argc, VALUE *argv, VALUE obj)
 } 
 
 static VALUE
-bdb_sary_subseq(VALUE obj, long beg, long len)
+bdb_sary_subseq(obj, beg, len)
+    VALUE obj;
+    long beg, len;
 {
     VALUE ary2, a;
     bdb_DB *dbst;
@@ -49,7 +53,8 @@ bdb_sary_subseq(VALUE obj, long beg, long len)
 }
 
 static VALUE
-bdb_sary_entry(VALUE obj, VALUE position)
+bdb_sary_entry(obj, position)
+    VALUE obj, position;
 {
     bdb_DB *dbst;
     long offset;
@@ -66,7 +71,9 @@ bdb_sary_entry(VALUE obj, VALUE position)
 }
 
 static VALUE
-bdb_sary_aref(int argc, VALUE *argv, VALUE obj)
+bdb_sary_aref(argc, argv, obj)
+    int argc;
+    VALUE *argv, obj;
 {
     VALUE arg1, arg2;
     long beg, len;
@@ -102,7 +109,9 @@ bdb_sary_aref(int argc, VALUE *argv, VALUE obj)
 }
 
 static VALUE
-bdb_intern_shift_pop(VALUE obj, int depart, int len)
+bdb_intern_shift_pop(obj, depart, len)
+    VALUE obj;
+    int depart, len;
 {
     bdb_DB *dbst;
     DB_TXN *txnid;
@@ -141,7 +150,9 @@ bdb_intern_shift_pop(VALUE obj, int depart, int len)
 }
 
 static void
-bdb_sary_replace(VALUE obj, VALUE beg, long len, long rpl)
+bdb_sary_replace(obj, beg, len, rpl)
+    VALUE obj, rpl;
+    long beg, len;
 {
     long i, j, rlen;
     VALUE tmp[2];
@@ -211,7 +222,10 @@ bdb_sary_replace(VALUE obj, VALUE beg, long len, long rpl)
 }
 
 static VALUE
-bdb_sary_aset(int argc, VALUE *argv, VALUE obj)
+bdb_sary_aset(argc, argv, obj)
+    int argc;
+    VALUE *argv;
+    VALUE obj;
 {
     long  beg, len;
     bdb_DB *dbst;
@@ -265,7 +279,10 @@ bdb_sary_aset(int argc, VALUE *argv, VALUE obj)
 #if RUBY_VERSION_CODE >= 172
 
 static VALUE
-bdb_sary_insert(int argc, VALUE *argv, VALUE obj)
+bdb_sary_insert(argc, argv, obj)
+    int argc;
+    VALUE *argv;
+    VALUE obj;
 {
     long pos;
 
@@ -290,13 +307,15 @@ bdb_sary_insert(int argc, VALUE *argv, VALUE obj)
 #endif
 
 static VALUE
-bdb_sary_at(VALUE obj, VALUE pos)
+bdb_sary_at(obj, pos)
+    VALUE obj, pos;
 {
     return bdb_sary_entry(obj, pos);
 }
 
 static VALUE
-bdb_sary_first(VALUE obj)
+bdb_sary_first(obj)
+    VALUE obj;
 {
     bdb_DB *dbst;
     VALUE tmp;
@@ -307,7 +326,8 @@ bdb_sary_first(VALUE obj)
 }
 
 static VALUE
-bdb_sary_last(VALUE obj)
+bdb_sary_last(obj)
+    VALUE obj;
 {
     bdb_DB *dbst;
     VALUE tmp;
@@ -319,7 +339,9 @@ bdb_sary_last(VALUE obj)
 }
 
 static VALUE
-bdb_sary_fetch(int argc, VALUE *argv, VALUE obj)
+bdb_sary_fetch(argc, argv, obj)
+    int argc;
+    VALUE *argv, obj;
 {
     VALUE pos, ifnone;
     bdb_DB *dbst;
@@ -341,7 +363,8 @@ bdb_sary_fetch(int argc, VALUE *argv, VALUE obj)
     
 
 static VALUE
-bdb_sary_concat(VALUE obj, VALUE y)
+bdb_sary_concat(obj, y)
+    VALUE obj, y;
 {
     bdb_DB *dbst;
     long i;
@@ -359,7 +382,8 @@ bdb_sary_concat(VALUE obj, VALUE y)
 }
     
 static VALUE
-bdb_sary_push(VALUE obj, VALUE y)
+bdb_sary_push(obj, y)
+    VALUE obj, y;
 {
     bdb_DB *dbst;
     VALUE tmp[2];
@@ -373,7 +397,9 @@ bdb_sary_push(VALUE obj, VALUE y)
 }
 
 static VALUE
-bdb_sary_push_m(int argc, VALUE *argv, VALUE obj)
+bdb_sary_push_m(argc, argv, obj)
+    int argc;
+    VALUE obj, *argv;
 {
     bdb_DB *dbst;
     long i;
@@ -395,7 +421,10 @@ bdb_sary_push_m(int argc, VALUE *argv, VALUE obj)
 }
 
 static VALUE
-bdb_sary_s_create(int argc, VALUE *argv, VALUE obj)
+bdb_sary_s_create(argc, argv, obj)
+    int argc;
+    VALUE *argv;
+    VALUE obj;
 {
     VALUE res;
 
@@ -410,7 +439,8 @@ bdb_sary_s_create(int argc, VALUE *argv, VALUE obj)
 }
     
 static VALUE
-bdb_sary_shift(VALUE obj)
+bdb_sary_shift(obj)
+    VALUE obj;
 {
     VALUE res;
     bdb_DB *dbst;
@@ -422,7 +452,8 @@ bdb_sary_shift(VALUE obj)
 }
 
 static VALUE
-bdb_sary_pop(VALUE obj)
+bdb_sary_pop(obj)
+    VALUE obj;
 {
     VALUE res;
     bdb_DB *dbst;
@@ -434,7 +465,10 @@ bdb_sary_pop(VALUE obj)
 }
 
 static VALUE
-bdb_sary_unshift_m(int argc, VALUE *argv, VALUE obj)
+bdb_sary_unshift_m(argc, argv, obj)
+    int argc;
+    VALUE *argv;
+    VALUE obj;
 {
     bdb_DB *dbst;
     VALUE tmp[2];
@@ -463,7 +497,8 @@ bdb_sary_unshift_m(int argc, VALUE *argv, VALUE obj)
 }
 
 static VALUE
-bdb_sary_length(VALUE obj)
+bdb_sary_length(obj)
+    VALUE obj;
 {
     bdb_DB *dbst;
 
@@ -473,7 +508,8 @@ bdb_sary_length(VALUE obj)
 }
 
 static VALUE
-bdb_sary_empty_p(VALUE obj)
+bdb_sary_empty_p(obj)
+    VALUE obj;
 {
     bdb_DB *dbst;
 
@@ -483,25 +519,29 @@ bdb_sary_empty_p(VALUE obj)
 }
 
 static VALUE
-bdb_sary_rindex(VALUE obj, VALUE a)
+bdb_sary_rindex(obj, a)
+    VALUE obj, a;
 {
     return bdb_internal_value(obj, a, Qtrue, DB_PREV);
 }
 
 static VALUE
-bdb_sary_to_a(VALUE obj)
+bdb_sary_to_a(obj)
+    VALUE obj;
 {
     return bdb_to_type(obj, rb_ary_new(), Qfalse);
 }
 
 static VALUE
-bdb_sary_reverse_m(VALUE obj)
+bdb_sary_reverse_m(obj)
+    VALUE obj;
 {
     return bdb_to_type(obj, rb_ary_new(), Qnil);
 }
 
 static VALUE
-bdb_sary_reverse_bang(VALUE obj)
+bdb_sary_reverse_bang(obj)
+    VALUE obj;
 {
     long i, j;
     bdb_DB *dbst;
@@ -527,13 +567,17 @@ bdb_sary_reverse_bang(VALUE obj)
 }
 
 static VALUE
-bdb_sary_collect_bang(int argc, VALUE *argv, VALUE obj)
+bdb_sary_collect_bang(argc, argv, obj)
+    int argc;
+    VALUE obj, *argv;
 {
     return bdb_each_kvc(argc, argv, obj, DB_NEXT, Qtrue, BDB_ST_VALUE);
 }
 
 static VALUE
-bdb_sary_collect(int argc, VALUE *argv, VALUE obj)
+bdb_sary_collect(argc, argv, obj)
+    int argc;
+    VALUE obj, *argv;
 {
     if (!rb_block_given_p()) {
 	return bdb_sary_to_a(obj);
@@ -542,7 +586,9 @@ bdb_sary_collect(int argc, VALUE *argv, VALUE obj)
 }
 
 static VALUE
-bdb_sary_select(int argc, VALUE *argv, VALUE obj)
+bdb_sary_select(argc, argv, obj)
+    int argc;
+    VALUE *argv, obj;
 {
     VALUE result;
     long i;
@@ -564,7 +610,9 @@ bdb_sary_select(int argc, VALUE *argv, VALUE obj)
 }
 
 static VALUE
-bdb_sary_values_at(int argc, VALUE *argv, VALUE obj)
+bdb_sary_values_at(argc, argv, obj)
+    int argc;
+    VALUE *argv, obj;
 {
     VALUE result;
     long i;
@@ -577,7 +625,9 @@ bdb_sary_values_at(int argc, VALUE *argv, VALUE obj)
 }
 
 static VALUE
-bdb_sary_indexes(int argc, VALUE *argv, VALUE obj)
+bdb_sary_indexes(argc, argv, obj)
+    int argc;
+    VALUE obj, *argv;
 {
 #if RUBY_VERSION_CODE >= 172
     rb_warn("Recnum#%s is deprecated; use Recnum#values_at",
@@ -587,14 +637,17 @@ bdb_sary_indexes(int argc, VALUE *argv, VALUE obj)
 }
 
 static VALUE
-bdb_sary_filter(int argc, VALUE *argv, VALUE obj)
+bdb_sary_filter(argc, argv, obj)
+    int argc;
+    VALUE obj, *argv;
 {
     rb_warn("BDB::Recnum#filter is deprecated; use BDB::Recnum#collect!");
     return bdb_sary_collect_bang(argc, argv, obj);
 }
 
 static VALUE
-bdb_sary_delete(VALUE obj, VALUE item)
+bdb_sary_delete(obj, item)
+    VALUE obj, item;
 {
     bdb_DB *dbst;
     long i1, i2;
@@ -623,7 +676,8 @@ bdb_sary_delete(VALUE obj, VALUE item)
 }
 
 static VALUE
-bdb_sary_delete_at_m(VALUE obj, VALUE a)
+bdb_sary_delete_at_m(obj, a)
+    VALUE obj, a;
 {
     bdb_DB *dbst;
     long pos;
@@ -644,7 +698,8 @@ bdb_sary_delete_at_m(VALUE obj, VALUE a)
 }
 
 static VALUE
-bdb_sary_reject_bang(VALUE obj)
+bdb_sary_reject_bang(obj)
+    VALUE obj;
 {
     bdb_DB *dbst;
     long i1, i2;
@@ -667,14 +722,16 @@ bdb_sary_reject_bang(VALUE obj)
 }
 
 static VALUE
-bdb_sary_delete_if(VALUE obj)
+bdb_sary_delete_if(obj)
+    VALUE obj;
 {
     bdb_sary_reject_bang(obj);
     return obj;
 }
 
 static VALUE
-bdb_sary_replace_m(VALUE obj, VALUE obj2)
+bdb_sary_replace_m(obj, obj2)
+    VALUE obj, obj2;
 {
     bdb_DB *dbst;
 
@@ -685,7 +742,9 @@ bdb_sary_replace_m(VALUE obj, VALUE obj2)
 }
 
 static VALUE
-bdb_sary_clear(int argc, VALUE *argv, VALUE obj)
+bdb_sary_clear(argc, argv, obj)
+    VALUE obj, *argv;
+    int argc;
 {
     bdb_DB *dbst;
     VALUE g;
@@ -710,7 +769,10 @@ bdb_sary_clear(int argc, VALUE *argv, VALUE obj)
 }
 
 static VALUE
-bdb_sary_fill(int argc, VALUE *argv, VALUE obj)
+bdb_sary_fill(argc, argv, obj)
+    int argc;
+    VALUE *argv;
+    VALUE obj;
 {
     VALUE item, arg1, arg2, tmp[2];
     long beg, len, i;
@@ -747,7 +809,8 @@ bdb_sary_fill(int argc, VALUE *argv, VALUE obj)
 }
 
 static VALUE
-bdb_sary_cmp(VALUE obj, VALUE obj2)
+bdb_sary_cmp(obj, obj2)
+    VALUE obj, obj2;
 {
     bdb_DB *dbst, *dbst2 = 0;
     VALUE a, a2, tmp, ary;
@@ -792,7 +855,10 @@ bdb_sary_cmp(VALUE obj, VALUE obj2)
 }
 
 static VALUE
-bdb_sary_slice_bang(int argc, VALUE *argv, VALUE obj)
+bdb_sary_slice_bang(argc, argv, obj)
+    int argc;
+    VALUE *argv;
+    VALUE obj;
 {
     VALUE arg1, arg2;
     long pos, len;
@@ -827,43 +893,50 @@ bdb_sary_slice_bang(int argc, VALUE *argv, VALUE obj)
 }
 
 static VALUE
-bdb_sary_plus(VALUE obj, VALUE y)
+bdb_sary_plus(obj, y)
+    VALUE obj, y;
 {
     return rb_ary_plus(bdb_sary_to_a(obj), y);
 }
 
 static VALUE
-bdb_sary_times(VALUE obj, VALUE y)
+bdb_sary_times(obj, y)
+    VALUE obj, y;
 {
     return rb_funcall(bdb_sary_to_a(obj), rb_intern("*"), 1, y);
 }
 
 static VALUE
-bdb_sary_diff(VALUE obj, VALUE y)
+bdb_sary_diff(obj, y)
+    VALUE obj, y;
 {
     return rb_funcall(bdb_sary_to_a(obj), rb_intern("-"), 1, y);
 }
 
 static VALUE
-bdb_sary_and(VALUE obj, VALUE y)
+bdb_sary_and(obj, y)
+    VALUE obj, y;
 {
     return rb_funcall(bdb_sary_to_a(obj), rb_intern("&"), 1, y);
 }
 
 static VALUE
-bdb_sary_or(VALUE obj, VALUE y)
+bdb_sary_or(obj, y)
+    VALUE obj, y;
 {
     return rb_funcall(bdb_sary_to_a(obj), rb_intern("|"), 1, y);
 }
 
 static VALUE
-bdb_sary_compact(VALUE obj)
+bdb_sary_compact(obj)
+    VALUE obj;
 {
     return rb_funcall(bdb_sary_to_a(obj), rb_intern("compact!"), 0, 0);
 }
 
 static VALUE
-bdb_sary_compact_bang(VALUE obj)
+bdb_sary_compact_bang(obj)
+    VALUE obj;
 {
     bdb_DB *dbst;
     long i, j;
@@ -887,7 +960,8 @@ bdb_sary_compact_bang(VALUE obj)
 }
 
 static VALUE
-bdb_sary_nitems(VALUE obj)
+bdb_sary_nitems(obj)
+    VALUE obj;
 {
     bdb_DB *dbst;
     long i, j;
